Description Usage Format Source
A dataset containing the full text of Michel Rodange's epic, Renert oder de Fuuß am Frack an a Ma'nsgrëßt in Luxembourguish.
1 |
A data frame with 6471 rows and 3 variables:
lineOriginal text
gesankSong; the text is subdivided in songs, called gesank in Luxembourguish
nb_lineLine number
https://data.public.lu/fr/datasets/the-works-in-luxembourguish-of-michel-rodange/
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.